<?php
/**
 * WordPress settings API demo class
 *
 * @author Tareq Hasan
 */
if ( !class_exists('HTService_Settings_API_Options' ) ):
class HTService_Settings_API_Options {

    private $settings_api;

    function __construct() {
        $this->settings_api = new HTService_Settings_API;

        add_action( 'admin_init', array($this, 'admin_init') );
        add_action( 'admin_menu', array($this, 'admin_menu') );
    }

    function admin_init() {

        //set the settings
        $this->settings_api->set_sections( $this->get_settings_sections() );
        $this->settings_api->set_fields( $this->get_settings_fields() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    function admin_menu() {
        add_submenu_page( 'htservice_menu', 'Settings', 'Settings', 'manage_options', 'htservice_options', array($this, 'htservice_options_page') );
    }

    function get_settings_sections() {
        $sections = array(
            array(
                'id'    => 'settings',
                'title' => __( 'Settings', 'htservice' )
            ),
            array(
                'id'    => 'pro_themes',
                'title' => __( 'Pro Theme using this plugins.', 'htservice' ),
            )
        );

        return $sections;
    }

    /**
     * Returns all the settings fields
     *
     * @return array settings fields
     */
    function get_settings_fields() {
        $settings_fields = array(
            'settings' => array(
                array(
                    'name'              => 'htservice_posts_per_page',
                    'label'             => __( 'Post Per Page', 'htservice' ),
                    'desc'              => __( 'Text input description', 'htservice' ),
                    'placeholder'       => __( 'Text Input placeholder', 'htservice' ),
                    'type'              => 'number',
                    'default'           => '10',
                    'sanitize_callback' => 'sanitize_text_field'
                ),

                array(
                    'name'              => 'htservice_posts_related_title',
                    'label'             => __( 'Related Title', 'htservice' ),
                    'desc'              => __( 'Text input description', 'htservice' ),
                    'placeholder'       => __( 'Related Movies', 'htservice' ),
                    'type'              => 'text',
                    'default'           => 'Related Services',
                    'sanitize_callback' => 'sanitize_text_field'
                ),
                array(
                    'name'    => 'htservice_featured_image_show',
                    'label'   => __( 'Featured Image Show/Hide', 'htservice' ),
                    'desc'    => __( 'Dropdown Options', 'htservice' ),
                    'type'    => 'select',
                    'default' => 'yes',
                    'options' => array(
                        'yes' => 'Show',
                        'no'  => 'Hide'
                    )
                ),
                array(
                    'name'    => 'htservice_title_show',
                    'label'   => __( 'Service Title Show/Hide', 'htservice' ),
                    'desc'    => __( 'Dropdown Options', 'htservice' ),
                    'type'    => 'select',
                    'default' => 'yes',
                    'options' => array(
                        'yes' => 'Show',
                        'no'  => 'Hide'
                    )
                ),
                array(
                    'name'    => 'htservice_related_service_show',
                    'label'   => __( 'Related Services Show/Hide', 'htservice' ),
                    'desc'    => __( 'Dropdown Options', 'htservice' ),
                    'type'    => 'select',
                    'default' => 'yes',
                    'options' => array(
                        'yes' => 'Show',
                        'no'  => 'Hide'
                    )
                ),
                array(
                    'name'    => 'htservice_related_service_style',
                    'label'   => __( 'Services Style', 'htservice' ),
                    'desc'    => __( 'Dropdown Options', 'htservice' ),
                    'type'    => 'radio',
                    'default' => 'yes',
                    'options' => array(
                        'ht_service_style1' => '<a class="ht_service_style" href= "'.HTSERVICE_ADDONS_PL_URL.'assets/images/style1.jpg ">Style One</a>',
                        'ht_service_style2' => '<a class="ht_service_style" href= "'.HTSERVICE_ADDONS_PL_URL.'assets/images/style2.jpg ">Style Two</a>',
                        'ht_service_style2 ht_hover_box' => '<a class="ht_service_style" href= "'.HTSERVICE_ADDONS_PL_URL.'assets/images/style3.jpg ">Style Three</a>',
                    )
                ),
            ),

        );

        return $settings_fields;
    }

    function htservice_options_page() {
        echo '<div class="wrap">';

        $this->settings_api->show_navigation();

        echo '<h2 class="nav-tab-wrapper"><a href="#settings" class="nav-tab" id="settings-tab">Settings</a><a href="#pro_themes" class="nav-tab nav-tab-active" id="pro_themes-tab">Pro Themes</a></h2>';

        $this->settings_api->show_forms();

        echo '</div>';
    }

    /**
     * Get all the pages
     *
     * @return array page names with key value pairs
     */
    function get_pages() {
        $pages = get_pages();
        $pages_options = array();
        if ( $pages ) {
            foreach ($pages as $page) {
                $pages_options[$page->ID] = $page->post_title;
            }
        }

        return $pages_options;
    }

}
endif;

new HTService_Settings_API_Options();